package
Version:
v0.0.0-...-9b31fef
Opens a new window with list of versions in this module.
Published: Sep 19, 2016
License: GPL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
locales
Package that provides GP locales definition. Based on https://github.com/GlotPress/gp-locales/.
How to build the library
gplocales.go is auto generated from go generate. See mkgplocales.go how
it generates the locales.
Documentation
¶
type Locale struct {
EnglishName string `json:"english_name"`
NativeName string `json:"native_name"`
LangCodeISO6391 string `json:"lang_code_iso_639_1"`
LangCodeISO6392 string `json:"lang_code_iso_639_2"`
LangCodeISO6393 string `json:"lang_code_iso_639_3"`
WPLocale string `json:"wp_locale"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.